@@ -77,13 +77,13 @@ class Horde_Rpc_Phpgw extends Horde_Rpc
         $method = str_replace('.', '/', 'phpgw.' . $method);
 
         if (!$registry->hasMethod($method)) {
-            Horde::logMessage(sprintf(Horde_Rpc_Translation::t("Method \"%s\" is not defined"), $method), 'NOTICE');
+            Horde::log(sprintf(Horde_Rpc_Translation::t("Method \"%s\" is not defined"), $method), 'NOTICE');
             return sprintf(Horde_Rpc_Translation::t("Method \"%s\" is not defined"), $method);
         }
 
         // Try to resume a session
         if (isset($params[0]['kp3']) && $params[0]["kp3"] == session_name() && session_id() != $params[0]["sessionid"]) {
-            Horde::logMessage("manually reload session ".$params[0]["sessionid"], 'NOTICE');
+            Horde::log("manually reload session ".$params[0]["sessionid"], 'NOTICE');
             session_regenerate_id();
             session_unset();
             session_id($params[0]["sessionid"]);
@@ -93,7 +93,7 @@ class Horde_Rpc_Phpgw extends Horde_Rpc
         $authenticated = $registry->isAuthenticated() || $method== "phpgw/system/login";
 
         if ($authenticated) {
-            Horde::logMessage("rpc call $method allowed", 'NOTICE');
+            Horde::log("rpc call $method allowed", 'NOTICE');
             return $registry->call($method, $params);
         } else {
             return PEAR::raiseError(Horde_Rpc_Translation::t("You did not authenticate."), 'horde.error');
@@ -124,7 +124,7 @@ class Horde_Rpc_Phpgw extends Horde_Rpc
             'User-Agent' => 'Horde RPC client',
             'Content-Type', 'text/xml');
         try {
-            $result = $client->post($url, xmlrpc_encode_request($method, $params), $headers);
+            $result = $client->post((string)$url, xmlrpc_encode_request($method, $params), $headers);
         } catch (Horde_Http_Exception $e) {
             throw new Horde_Rpc_Exception($result);
         }
